@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.7.3-1
+# Application Name - Health Check V0.9.0-0
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -17,6 +17,7 @@
 # import PyQt4 & sys
 print "** Start Imports **"
 print "** Importing qtcore & gui **"
+
 try:
 	from PyQt4 import QtCore, QtGui
 except:
@@ -145,6 +146,7 @@ rootfs_id = ''
 class imagea(QtGui.QMainWindow):
 
 	def __init__(self, *args):
+		
 		apply(QtGui.QMainWindow.__init__, (self,) + args)
 		print "** Starting Hellowindow Class **"
 		#self.Qt::WA_Maemo5StackedWindow 
@@ -153,6 +155,7 @@ class imagea(QtGui.QMainWindow):
 		print "** Setting window details and loading form**"
 		self.setGeometry(0, 0, 800, 480)
 		self.setWindowTitle('Front Camera Image')
+		
 
 		self.lbl_CameraShow = QtGui.QLabel(self)
 		self.lbl_CameraShow.setGeometry(QtCore.QRect(160, 10, 455, 341))
@@ -231,36 +234,36 @@ class imagea(QtGui.QMainWindow):
 		gl = gl.strip()
 
 		if str(gl) == "closed":
-                        self.CloseDialog = QtGui.QMessageBox.question(None,"WARNING - Camera Shutter is Closed"," Please open the shutter and click yes when ready. \n Click no to cancel", QtGui.QMessageBox.Yes|QtGui.QMessageBox.No,QtGui.QMessageBox.No)
-                        if self.CloseDialog == QtGui.QMessageBox.Yes:
-                                print "** Please open the shutter and click yes when ready ** \n Click no to cancel"
-                                # Close b - the greatly named variable - as i want to use it again! (Well close or declare it!)
-                                b = None
-                                # X-term - grab 10 buffered front camera images, and throw them into an image file.
-                                # Everyone recommends 1.... but 10 gave more light! - so i used it :D
-                                b = os.popen('gst-launch v4l2camsrc device=/dev/video0 num-buffers=10 ! dspjpegenc ! filesink location=/home/user/MyDocs/fcamtest.jpg')
-                                b.close ()
-                                # Declare and set the image file name
-                                image_file = "/home/user/MyDocs/fcamtest.jpg"
-                                image = QtGui.QPixmap(image_file)
-                                # Declare image, and tell it, that it is a pixmap, and it will be a pixmap of the file we have just set.
-                                self.lbl_CameraShow.setPixmap(image)
-                                print " ** Finished Back camera function **"
-                        elif self.CloseDialog == QtGui.QMessageBox.No:
-                                print "** User pressed 'No' button - returning **"
+			self.CloseDialog = QtGui.QMessageBox.question(None,"WARNING - Camera Shutter is Closed"," Please open the shutter and click yes when ready. \n Click no to cancel", QtGui.QMessageBox.Yes|QtGui.QMessageBox.No,QtGui.QMessageBox.No)
+			if self.CloseDialog == QtGui.QMessageBox.Yes:
+				print "** Please open the shutter and click yes when ready ** \n Click no to cancel"
+				# Close b - the greatly named variable - as i want to use it again! (Well close or declare it!)
+				b = None
+				# X-term - grab 10 buffered front camera images, and throw them into an image file.
+				# Everyone recommends 1.... but 10 gave more light! - so i used it :D
+				b = os.popen('gst-launch v4l2camsrc device=/dev/video0 num-buffers=10 ! dspjpegenc ! filesink location=/home/user/MyDocs/fcamtest.jpg')
+				b.close ()
+				# Declare and set the image file name
+				image_file = "/home/user/MyDocs/fcamtest.jpg"
+				image = QtGui.QPixmap(image_file)
+				# Declare image, and tell it, that it is a pixmap, and it will be a pixmap of the file we have just set.
+				self.lbl_CameraShow.setPixmap(image)
+				print " ** Finished Back camera function **"
+			elif self.CloseDialog == QtGui.QMessageBox.No:
+				print "** User pressed 'No' button - returning **"
 		else:
-        		# Close b - the greatly named variable - as i want to use it again! (Well close or declare it!)
-                        b = None
-                        # X-term - grab 10 buffered front camera images, and throw them into an image file.
-                        # Everyone recommends 1.... but 10 gave more light! - so i used it :D
-                        b = os.popen('gst-launch v4l2camsrc device=/dev/video0 num-buffers=10 ! dspjpegenc ! filesink location=/home/user/MyDocs/fcamtest.jpg')
-                        b.close ()
-                        # Declare and set the image file name
-                        image_file = "/home/user/MyDocs/fcamtest.jpg"
-                        image = QtGui.QPixmap(image_file)
-                        # Declare image, and tell it, that it is a pixmap, and it will be a pixmap of the file we have just set.
-                        self.lbl_CameraShow.setPixmap(image)
-                        print " ** Finished Back camera function **"
+			# Close b - the greatly named variable - as i want to use it again! (Well close or declare it!)
+			b = None
+			# X-term - grab 10 buffered front camera images, and throw them into an image file.
+			# Everyone recommends 1.... but 10 gave more light! - so i used it :D
+			b = os.popen('gst-launch v4l2camsrc device=/dev/video0 num-buffers=10 ! dspjpegenc ! filesink location=/home/user/MyDocs/fcamtest.jpg')
+			b.close ()
+			# Declare and set the image file name
+			image_file = "/home/user/MyDocs/fcamtest.jpg"
+			image = QtGui.QPixmap(image_file)
+			# Declare image, and tell it, that it is a pixmap, and it will be a pixmap of the file we have just set.
+			self.lbl_CameraShow.setPixmap(image)
+			print " ** Finished Back camera function **"
 
 
 
@@ -367,7 +370,7 @@ class HelloWindow(QtGui.QMainWindow):
 class Ui_MainWindow(object):
 	def setupUi(self, MainWindow):
 
-                print "** start SetupUi**"
+		print "** start SetupUi**"
 		# declaring the previous var_g_GPS location as a global in here, this allows it to be read in here.
 		global var_g_GPS
 
@@ -402,8 +405,8 @@ class Ui_MainWindow(object):
 		QtCore.QObject.connect(actc, QtCore.SIGNAL("triggered()"), self.updateTab2)
 		#fremantle = MainWindow.menuBar().addMenu("Applications");
 		#MainWindow.menuBar().addSeparator()
-		actd = fremantle.addAction("Apps")
-		QtCore.QObject.connect(actd, QtCore.SIGNAL("triggered()"), self.listpackages)
+		#actd = fremantle.addAction("Apps")
+		#QtCore.QObject.connect(actd, QtCore.SIGNAL("triggered()"), self.listpackages)
 
 
 
@@ -481,52 +484,52 @@ class Ui_MainWindow(object):
 		self.tabWidget.addTab(self.tab_2, "")
 
 		# Start on tab 3!
-		self.tab_3 = QtGui.QWidget()
-		self.tab_3.setObjectName("tab_3")
+		#self.tab_3 = QtGui.QWidget()
+		#self.tab_3.setObjectName("tab_3")
 
-		font = QtGui.QFont()
-		font.setPointSize(12)
+		#font = QtGui.QFont()
+		#font.setPointSize(12)
 		# Set up the Front Camera label
 
 		# This label is used to show the Front Camera widget
-		self.listApps = QtGui.QListWidget(self.tab_3)
-		self.listApps.setGeometry(QtCore.QRect(1, 0, 799, 361))
-		self.listApps.setObjectName("listApps")
-		self.listApps.setFont(font)
-		self.listApps.setAlternatingRowColors(True)
-		self.listApps.setSizePolicy(QtGui.QSizePolicy.Minimum,QtGui.QSizePolicy.Minimum)
-		self.listApps.setResizeMode(QtGui.QListView.Adjust)
+		#self.listApps = QtGui.QListWidget(self.tab_3)
+		#self.listApps.setGeometry(QtCore.QRect(1, 0, 799, 361))
+		#self.listApps.setObjectName("listApps")
+		#self.listApps.setFont(font)
+		#self.listApps.setAlternatingRowColors(True)
+		#self.listApps.setSizePolicy(QtGui.QSizePolicy.Minimum,QtGui.QSizePolicy.Minimum)
+		#self.listApps.setResizeMode(QtGui.QListView.Adjust)
 		
 
 		# Show the tab and draw contents
-		self.tabWidget.addTab(self.tab_3, "")
+		#self.tabWidget.addTab(self.tab_3, "")
 
 		# Start on tab 4!
-		self.tab_4 = QtGui.QWidget()
-		self.tab_4.setObjectName("tab_4")
+		self.tab_3 = QtGui.QWidget()
+		self.tab_3.setObjectName("tab_3")
 
-		self.pushButton_snd1 = QtGui.QPushButton(self.tab_4)
+		self.pushButton_snd1 = QtGui.QPushButton(self.tab_3)
 		self.pushButton_snd1.setGeometry(QtCore.QRect(10, 10, 391, 51))
 		self.pushButton_snd1.setObjectName("pushButton_snd1")
 		self.pushButton_snd1.setText("Test Sound")
 		# Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
 		QtCore.QObject.connect(self.pushButton_snd1, QtCore.SIGNAL('clicked()'), self.updatesound)
 
-		self.pushButton_led = QtGui.QPushButton(self.tab_4)
+		self.pushButton_led = QtGui.QPushButton(self.tab_3)
 		self.pushButton_led.setGeometry(QtCore.QRect(10, 70, 391, 51))
 		self.pushButton_led.setObjectName("pushButton_led")
 		self.pushButton_led.setText("Test LEDs")
 		# Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
 		QtCore.QObject.connect(self.pushButton_led, QtCore.SIGNAL('clicked()'), self.updateLED)
 
-		self.pushButton_von = QtGui.QPushButton(self.tab_4)
+		self.pushButton_von = QtGui.QPushButton(self.tab_3)
 		self.pushButton_von.setGeometry(QtCore.QRect(10, 130, 391, 51))
 		self.pushButton_von.setObjectName("pushButton_von")
 		self.pushButton_von.setText("Test Vibrate")
 		# Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
 		QtCore.QObject.connect(self.pushButton_von, QtCore.SIGNAL('clicked()'), self.vibrateon)
 
-		self.xyscreen = QtGui.QPushButton(self.tab_4)
+		self.xyscreen = QtGui.QPushButton(self.tab_3)
 		self.xyscreen.setGeometry(QtCore.QRect(10, 190, 391, 51))
 		self.xyscreen.setObjectName("xyscreen")
 		self.xyscreen.setText("Accuracy Test")
@@ -534,7 +537,7 @@ class Ui_MainWindow(object):
 		QtCore.QObject.connect(self.xyscreen, QtCore.SIGNAL('clicked()'), self.show_new_window2)
 
 		# Setup and draw the button
-		self.pushButton_cama = QtGui.QPushButton(self.tab_4)
+		self.pushButton_cama = QtGui.QPushButton(self.tab_3)
 		self.pushButton_cama.setGeometry(QtCore.QRect(10, 250, 391, 51))
 		self.pushButton_cama.setObjectName("pushButton_cama")
 		self.pushButton_cama.setText("Camera Tests")
@@ -542,7 +545,7 @@ class Ui_MainWindow(object):
 		QtCore.QObject.connect(self.pushButton_cama, QtCore.SIGNAL('clicked()'), self.updateimage)
 		
 		# Setup and draw the button
-		self.pushButton_reboot = QtGui.QPushButton(self.tab_4)
+		self.pushButton_reboot = QtGui.QPushButton(self.tab_3)
 		self.pushButton_reboot.setGeometry(QtCore.QRect(10, 310, 391, 51))
 		self.pushButton_reboot.setObjectName("pushButton_reboot")
 		self.pushButton_reboot.setText("System Reboot")
@@ -550,7 +553,7 @@ class Ui_MainWindow(object):
 		QtCore.QObject.connect(self.pushButton_reboot, QtCore.SIGNAL('clicked()'), self.reboot_sys)
 
 
-		self.sound_lst = QtGui.QComboBox(self.tab_4)
+		self.sound_lst = QtGui.QComboBox(self.tab_3)
 		self.sound_lst.setGeometry(QtCore.QRect(400, 10, 391, 51))
 		self.sound_lst.setObjectName("sound_lst")
 		for f in os.listdir("/usr/share/sounds/"):
@@ -559,7 +562,7 @@ class Ui_MainWindow(object):
 				self.sound_lst.addItem(f)
 		#self.sound_lst.addItem("PatternIncomingCall")
 
-		self.combo_led = QtGui.QComboBox(self.tab_4)
+		self.combo_led = QtGui.QComboBox(self.tab_3)
 		self.combo_led.setGeometry(QtCore.QRect(400, 70, 391, 51))
 		self.combo_led.setObjectName("combo_led")
 		self.combo_led.addItem("PatternError")
@@ -568,7 +571,7 @@ class Ui_MainWindow(object):
 		self.combo_led.addItem("PatternCommunicationCall")
 		self.combo_led.addItem("PatternCommunicationSMS")
 
-		self.vibra_led = QtGui.QComboBox(self.tab_4)
+		self.vibra_led = QtGui.QComboBox(self.tab_3)
 		self.vibra_led.setGeometry(QtCore.QRect(400, 130, 391, 51))
 		self.vibra_led.setObjectName("vibra_led")
 		self.vibra_led.addItem("PatternIncomingCall")
@@ -577,7 +580,7 @@ class Ui_MainWindow(object):
 		#self.vibra_led.addItem("PatternTouchScreen")
 		self.vibra_led.addItem("PatternChatAndEmail")
 
-		self.color_test = QtGui.QPushButton(self.tab_4)
+		self.color_test = QtGui.QPushButton(self.tab_3)
 		self.color_test.setGeometry(QtCore.QRect(400, 190, 391, 51))
 		self.color_test.setObjectName("color_test")
 		self.color_test.setText("Dead Pixel Test")
@@ -588,23 +591,23 @@ class Ui_MainWindow(object):
 		# Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
 		#QtCore.QObject.connect(self.pushButton_von, QtCore.SIGNAL('clicked()'), self.vibrateon)
 
-		self.tabWidget.addTab(self.tab_4, "")
+		self.tabWidget.addTab(self.tab_3, "")
 
 		# Start on tab 5!
-		self.tab_5 = QtGui.QWidget()
-		self.tab_5.setObjectName("tab_5")
+		self.tab_4 = QtGui.QWidget()
+		self.tab_4.setObjectName("tab_4")
 
 		# Create the text browser to show the large console input
 		# I have used this to show i could get the information in to begin with... I will eventually parse this information and put it into a list
 		# box of some sort
-		self.textBrowser = QtGui.QTextBrowser(self.tab_5)
+		self.textBrowser = QtGui.QTextBrowser(self.tab_4)
 		self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-		self.textBrowser.setText (" Health Check V0.7.3-1 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457 \n\n Thanks to: Mikec(Accuracy test), Rob1n(App window) & Lcuk(Everything!)\n And to all the testers.")
+		self.textBrowser.setText (" Health Check V0.9.0-0 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457 \n\n Thanks to: Mikec(Accuracy test), Rob1n(App window) & Lcuk(Everything!)\n And to all the testers.")
 		# Make the font small!!!
 		font = QtGui.QFont()
 		font.setPointSize(20)
 		self.textBrowser.setFont(font)
-		self.tabWidget.addTab(self.tab_5, "")
+		self.tabWidget.addTab(self.tab_4, "")
 
 		# Draw the main Window
 		MainWindow.setCentralWidget(self.centralwidget)
@@ -613,24 +616,11 @@ class Ui_MainWindow(object):
 		print "** Run retranslateUi **"
 		self.retranslateUi(MainWindow)
 		#self.updateTab1()
-		self.updateAll()
+		
 		# Set which tab you want showing on program load
 		print "** Show tab1 (0) **"
 		self.tabWidget.setCurrentIndex(0)
 		QtCore.QMetaObject.connectSlotsByName(MainWindow)
-		
-		
-
-		#QtCore.QObject.connect(self.tabWidget,QtCore.SIGNAL("currentChanged(int)"), self.tab_change)
-
-	def tab_change(self, tab_id):
-                print tab_id
-                if tab_id == 0:
-                        #self.updateTab1()
-                        print tab_id
-                elif tab_id == 1:
-                        self.updateTab2()
-
 
 	def show_new_window(self):           
 		win.show()
@@ -646,27 +636,27 @@ class Ui_MainWindow(object):
 
 	def listpackages(self):
 
-                self.listApps.clear()
-                self.checkpkgs()
-                self.listApps.sortItems()		
+		self.listApps.clear()
+		self.checkpkgs()
+		self.listApps.sortItems()		
 
 	
 
 	# Get the total rootfs size for all non-l10n packages
 	def checkpkgs(self):
-                print " ** Getting applications list **"
+		print " ** Getting applications list **"
 		#gl = os.popen('grep Package: /var/lib/dpkg/available').read()
 		fh = open("/var/lib/dpkg/available","r")
-                igot = fh.readlines()
-                print " ** Adding applications to listbox **"
-                for line in igot:
-                        if line.find("Package:") > -1:
-                                about = line.split()
-                                #print about[0],
-                                self.listApps.addItem(about[1])
-                                self.listApps.sortItems()
-                                
-                
+		igot = fh.readlines()
+		print " ** Adding applications to listbox **"
+		for line in igot:
+			if line.find("Package:") > -1:
+				about = line.split()
+				#print about[0],
+				self.listApps.addItem(about[1])
+				self.listApps.sortItems()
+				
+		
 		
 # Funtion - update GPS - Using lib-location
 	def updateGPS(self, MainWindow):
@@ -813,32 +803,32 @@ class Ui_MainWindow(object):
 		gd = gd.strip()
 		self.listWidget.addItem("Boot Count \t\t\t" + gd.strip())
 
-                print " ** Getting FM Transmitter power level **"
+		print " ** Getting FM Transmitter power level **"
 		ge = os.popen('cat /sys/class/i2c-adapter/i2c-2/2-0063/power_level').read()
 		ge = ge.strip()
 		self.listWidget.addItem("FM Trans Strength \t\t" + ge.strip())
 
-                print " ** Getting Boot Reason**"
+		print " ** Getting Boot Reason**"
 		gl = os.popen('cat /proc/bootreason').read()
 		gl = gl.strip()	
 		self.listWidget.addItem("Boot Reason (last) \t\t" + gl.strip())
 
-                print " ** Getting Cam Shutter State**"
+		print " ** Getting Cam Shutter State**"
 		gl = os.popen('cat /sys/devices/platform/gpio-switch/cam_shutter/state').read()
 		gl = gl.strip()
 		self.listWidget.addItem("Camera Shutter State \t" + gl.strip())
 
-                print " ** Getting Keyboard Slider State**"
+		print " ** Getting Keyboard Slider State**"
 		gl = os.popen('cat /sys/devices/platform/gpio-switch/slide/state').read()
 		gl = gl.strip()
 		self.listWidget.addItem("Keyboard Slider State \t" + gl.strip())
 
-                print " ** Getting proximity sensor state**"
+		print " ** Getting proximity sensor state**"
 		gl = os.popen('cat /sys/devices/platform/gpio-switch/proximity/state').read()
 		gl = gl.strip()
 		self.listWidget.addItem("Proximity Sensor State \t" + gl.strip())
 
-                print " ** Getting headphone state**"
+		print " ** Getting headphone state**"
 		gl = os.popen('cat /sys/devices/platform/gpio-switch/headphone/state').read()
 		gl = gl.strip()
 		self.listWidget.addItem("Headphone State \t\t" + gl.strip())
@@ -848,7 +838,7 @@ class Ui_MainWindow(object):
 		gl = gl.strip()
 		self.listWidget.addItem("Battery current mAh \t\t" + gl.strip())
 		
-                print " ** Getting battery mAh info2**"
+		print " ** Getting battery mAh info2**"
 		gl = os.popen('hal-device bme | awk \'/g.la/ {print $3" mAh"}\'').read()
 		gl = gl.strip()
 		self.listWidget.addItem("Battery last charge mAh \t" + gl.strip())
@@ -880,22 +870,22 @@ class Ui_MainWindow(object):
 		#self.listWidget.addItem("Phone Registration \t" + b.strip())
 
 		print " ** Getting IP INFO*"
-                ga = os.popen('/sbin/ifconfig | awk \'/Bc/ {print $2}\' | cut -c6-').read()
+		ga = os.popen('/sbin/ifconfig | awk \'/Bc/ {print $2}\' | cut -c6-').read()
 		ga = ga.strip()
 		self.listWidget2.addItem("IP Internal \t\t" + ga.strip())
 
 		print " ** Getting Wireless Info*"
-                ga = os.popen('cat /proc/net/wireless | awk \'/0/ {print $3}\' | awk -F. \'/./ {print $1" %"}\'').read()
+		ga = os.popen('cat /proc/net/wireless | awk \'/0/ {print $3}\' | awk -F. \'/./ {print $1" %"}\'').read()
 		ga = ga.strip()
 		self.listWidget2.addItem("WIFI Link Quality \t" + ga.strip())
 
 		print " ** Getting Wireless Info RSSI*"
-                ga = os.popen('cat /proc/net/wireless | awk \'/0/ {print $4" dBm"}\'').read()
+		ga = os.popen('cat /proc/net/wireless | awk \'/0/ {print $4" dBm"}\'').read()
 		ga = ga.strip()
 		self.listWidget2.addItem("WIFI RSSI \t\t" + ga.strip())
 		
 		print " ** Getting Wireless Info Noise*"
-                ga = os.popen('cat /proc/net/wireless | awk \'/0/ {print $5}\' | awk -F. \'/./ {print $1" dBm"}\'').read()
+		ga = os.popen('cat /proc/net/wireless | awk \'/0/ {print $5}\' | awk -F. \'/./ {print $1" dBm"}\'').read()
 		ga = ga.strip()
 		self.listWidget2.addItem("WIFI Noise \t\t" + ga.strip())
 
@@ -1033,7 +1023,7 @@ class Ui_MainWindow(object):
 		gl = gl.strip()
 		self.listWidget.addItem("MyDocs MB Free \t\t" + gl.strip())
 
-                print " ** Getting App Space **"
+		print " ** Getting App Space **"
 		gl = os.popen('df /home | awk \'/ho/ {print $5}\'').read()
 		gl = gl.strip()
 		self.listWidget.addItem("App/Home % Used \t\t" + gl.strip())
@@ -1056,12 +1046,17 @@ class Ui_MainWindow(object):
 		print " ** Getting CPU Frequency **"
 		gl = os.popen('echo $((`cat /sys/devices/system/cpu/cpu0/cpufreq/scaling_cur_freq`/1000)) MHz').read()
 		gl = gl.strip()
-		self.listWidget.addItem("CPU Frequency \t\t" + gl.strip())
-
-		print " ** Getting CPU Temperature **"
-		gl = os.popen('cat /sys/devices/platform/omap34xx_temp/temp1_input').read()
+		self.listWidget.addItem("CPU Current Freq \t\t" + gl.strip())
+		
+		print " ** Getting CPU Frequency **"
+		gl = os.popen('echo $((`cat /sys/devices/system/cpu/cpu0/cpufreq/scaling_max_freq`/1000)) MHz').read()
 		gl = gl.strip()
-		self.listWidget.addItem("CPU Temp (celcius) \t\t" + gl.strip())
+		self.listWidget.addItem("CPU Max Freq \t\t" + gl.strip())
+
+		#print " ** Getting CPU Temperature **"
+		#gl = os.popen('cat /sys/devices/platform/omap34xx_temp/temp1_input').read()
+		#gl = gl.strip()
+		#self.listWidget.addItem("CPU Temp (celcius) \t\t" + gl.strip())
 
 		#print " ** Getting RAM Used **"
 		#gl = os.popen('free | awk \'/M/ {printf ("%.1f MB\n",$3/1024)}\'').read()
@@ -1088,6 +1083,13 @@ class Ui_MainWindow(object):
 		gl = gl.strip()
 		self.listWidget.addItem("Kernel Core Info \t\t" + gl.strip())
 
+		print " ** Getting MMC Cover/latch **"
+		gl = os.popen('cat /sys/class/mmc_host/mmc0/cover_switch').read()
+		gl = gl.strip()
+		self.listWidget.addItem("MMC Cover State \t\t" + gl.strip())
+
+		
+
 
 		
 
@@ -1095,109 +1097,240 @@ class Ui_MainWindow(object):
 # Funtion - update tab.... Originally to update tab1, but using it to collate the functions
 # It has the commented out message boxes, will work on this later
 	def updateAll(self):
+                
 		print " ** Running Update ALL**"
-		self.updateTab1()
-		self.updateTab2()
-		self.listpackages()
+		progress = QtGui.QProgressDialog("Please Wait", "Cancel", 0, 100, MainWindow)
+		progress.setWindowModality(QtCore.Qt.WindowModal)
+		progress.setAutoReset(True)
+		progress.setAutoClose(True)
+		progress.setMinimum(0)
+		progress.setMaximum(100)
+		progress.resize(800,200)
+		progress.setWindowTitle("Loading Healthcheck")
+		progress.show()
+		QtGui.QApplication.processEvents()
+		time.sleep(0.5)
+                progress.setValue(0)
+
+                print " ** Running tab1 update ** "
+                self.listWidget.clear()
+                self.updaterootfs()
+                progress.setWindowTitle("Loading Healthcheck - Rootfs")
+                QtGui.QApplication.processEvents()
+                time.sleep(0.3)
+                progress.setValue(15)
+                self.updateAccel()
+                progress.setWindowTitle("Loading Healthcheck - Accelerometer")
+                QtGui.QApplication.processEvents()
+                time.sleep(0.3)
+                progress.setValue(30)
+                self.updateCPU()
+                progress.setWindowTitle("Loading Healthcheck - CPU")
+                QtGui.QApplication.processEvents()
+                time.sleep(0.3)
+                progress.setValue(45)
+                self.updateMaemoV()
+                progress.setWindowTitle("Loading Healthcheck - Firmware")
+                QtGui.QApplication.processEvents()
+                time.sleep(0.3)
+                progress.setValue(60)
+                self.updateUptime()
+                progress.setWindowTitle("Loading Healthcheck - Uptime")
+                QtGui.QApplication.processEvents()
+                time.sleep(0.3)
+                progress.setValue(70)
+                self.updateBatt()
+                progress.setWindowTitle("Loading Healthcheck - Battery")
+                QtGui.QApplication.processEvents()
+                time.sleep(0.3)
+                self.listWidget.sortItems()
+                print " ** Finished tab 1 update **"
+
+                print " ** Starting tab 2 update**"
+		self.listWidget2.clear()
+		self.updateGPS(MainWindow)
+		progress.setWindowTitle("Loading Healthcheck - GPS")
+		QtGui.QApplication.processEvents()
+                time.sleep(0.3)
+                progress.setValue(80)
+		self.Cellular(MainWindow)
+		progress.setWindowTitle("Loading Healthcheck - Cell/Phone")
+		QtGui.QApplication.processEvents()
+                time.sleep(0.3)
+                progress.setValue(90)
+		self.updatenetname()
+		progress.setWindowTitle("Loading Healthcheck - Networks")
+		self.listWidget2.sortItems()
+                progress.setValue(100)
+                time.sleep(0.3)
+                print " ** Finished tab 2 update **"
+                print " ** Finished ALL Update **"
+		print 'done'
+                progress.hide()
+
 	
 	def updateTab1(self):
-		print " ** Running tab1 update**"
-		#import hildon
-		self.listWidget.clear()
-		#self.pushButton_hw.setEnabled(False)
-		#self.pushButton_a1.setEnabled(False)
-		self.updaterootfs()
-		self.updateAccel()
-		self.updateCPU()
-		self.updateMaemoV()
-		self.updateUptime()
-		self.updateBatt()
-		self.listWidget.sortItems()
-		bus = dbus.SessionBus()
-		proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
-		interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
-		interface.Notify('HealthCheck', 0, 'general_refresh', 'System Tab', 'Finished Loading', [], {}, 2000)
-		print " ** Finished tab 1 update**"
+		print " ** Running tab1 - load progress**"
+		progress = QtGui.QProgressDialog("Please Wait", "Cancel", 0, 100, MainWindow)
+		progress.setWindowModality(QtCore.Qt.WindowModal)
+		progress.setAutoReset(True)
+		progress.setAutoClose(True)
+		progress.setMinimum(0)
+		progress.setMaximum(100)
+		progress.resize(800,200)
+		progress.setWindowTitle("Loading System")
+		progress.show()
+		QtGui.QApplication.processEvents()
+		time.sleep(0.5)
+                progress.setValue(0)
+
+                print " ** Running tab1 update ** "
+                self.listWidget.clear()
+                self.updaterootfs()
+                progress.setWindowTitle("Loading System - Rootfs")
+                QtGui.QApplication.processEvents()
+                time.sleep(0.3)
+                progress.setValue(20)
+                self.updateAccel()
+                progress.setWindowTitle("Loading System - Accelerometer")
+                QtGui.QApplication.processEvents()
+                time.sleep(0.3)
+                progress.setValue(40)
+                self.updateCPU()
+                progress.setWindowTitle("Loading System - CPU")
+                QtGui.QApplication.processEvents()
+                time.sleep(0.3)
+                progress.setValue(60)
+                self.updateMaemoV()
+                progress.setWindowTitle("Loading System - Firmware")
+                QtGui.QApplication.processEvents()
+                time.sleep(0.3)
+                progress.setValue(80)
+                self.updateUptime()
+                progress.setWindowTitle("Loading System - Uptime")
+                QtGui.QApplication.processEvents()
+                time.sleep(0.3)
+                progress.setValue(90)
+                self.updateBatt()
+                progress.setWindowTitle("Loading System - Battery")
+                QtGui.QApplication.processEvents()
+                time.sleep(0.3)
+                self.listWidget.sortItems()
+                print " ** Finished tab 1 update **"
+
+                progress.setValue(100)
+                time.sleep(0.3)
+		print 'done'
+                progress.hide()
 
 	def updateTab2(self):
-		print " ** Starting tab 2 update**"
+		print " ** Running tab 2 progress**"
+		progress = QtGui.QProgressDialog("Please Wait", "Cancel", 0, 100, MainWindow)
+		progress.setWindowModality(QtCore.Qt.WindowModal)
+		progress.setAutoReset(True)
+		progress.setAutoClose(True)
+		progress.setMinimum(0)
+		progress.setMaximum(100)
+		progress.resize(800,200)
+		progress.setWindowTitle("Loading Comms")
+		progress.show()
+		QtGui.QApplication.processEvents()
+		time.sleep(0.5)
+                progress.setValue(0)
+
+                print " ** Starting tab 2 update**"
 		self.listWidget2.clear()
-		#self.pushButton_com.setEnabled(False)
-		#self.pushButton_a2.setEnabled(False)
+		progress.setValue(20)
 		self.updateGPS(MainWindow)
+		progress.setWindowTitle("Loading Comms - GPS")
+		QtGui.QApplication.processEvents()
+                time.sleep(0.3)
+                progress.setValue(40)
 		self.Cellular(MainWindow)
+		progress.setWindowTitle("Loading Comms- Cell/Phone")
+		QtGui.QApplication.processEvents()
+                time.sleep(0.3)
+                progress.setValue(80)
 		self.updatenetname()
+		progress.setWindowTitle("Loading Comms - Networks")
 		self.listWidget2.sortItems()
-		bus = dbus.SessionBus()
-		proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
-		interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
-		interface.Notify('HealthCheck', 0, 'general_refresh', 'Comms Tab', 'Finished Loading', [], {}, 2000)
-		print " ** Finished Tab 2 update **"
+                progress.setValue(100)
+                time.sleep(0.3)
+                print " ** Finished tab 2 update **"
+
+		print 'done'
+                progress.hide()
+
+		#bus = dbus.SessionBus()
+		#proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
+		#interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
+		#interface.Notify('HealthCheck', 0, 'general_refresh', 'Comms Tab', 'Finished Loading', [], {}, 2000)
+		#print " ** Finished Tab 2 update **"
 
   
 		
 	# This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
 	def retranslateUi(self, MainWindow):
-		MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check V0.7.3-1", None, QtGui.QApplication.UnicodeUTF8))
+		MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check V0.9.0-0", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
-		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Apps", None, QtGui.QApplication.UnicodeUTF8))
-		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_4), QtGui.QApplication.translate("MainWindow", "Tools", None, QtGui.QApplication.UnicodeUTF8))
-		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_5), QtGui.QApplication.translate("MainWindow", "About", None, QtGui.QApplication.UnicodeUTF8))
+		#self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Apps", None, QtGui.QApplication.UnicodeUTF8))
+		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Tools", None, QtGui.QApplication.UnicodeUTF8))
+		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_4), QtGui.QApplication.translate("MainWindow", "About", None, QtGui.QApplication.UnicodeUTF8))
 		
 # Cell_info - Taken from netmon code. Need to figure out the author so i can give proper thanks!
 # can be found here - http://repository.maemo.org/extras-devel/pool/fremantle/free/source/n/netmon/
 	def Cellular(self,MainWindow):
 		print " ** Starting Cellular*"
-                #import dbus
+		#import dbus
 	
-                regstatus = gn_cellinfo.RegStatus()
-                signalstrength = gn_cellinfo.SignalStrength()
+		regstatus = gn_cellinfo.RegStatus()
+		signalstrength = gn_cellinfo.SignalStrength()
 
-                if (regstatus[0] == 0): status = 'home'
-                elif (regstatus[0] == 1): status = 'roam'
-                elif (regstatus[0] == 2): status = 'roam_blink'
-                elif (regstatus[0] == 3): status = 'no serv.'
-                elif (regstatus[0] == 4): status = 'no serv. search'
-                elif (regstatus[0] == 5): status = 'no serv. no search'
-                elif (regstatus[0] == 6): status = 'no sim'
-                elif (regstatus[0] == 8): status = 'power off'
-                elif (regstatus[0] == 9): status = 'nsps'
-                elif (regstatus[0] == 10): status = 'nsps no cover.'
-                elif (regstatus[0] == 10): status = 'sim rejected'
-                else: status = 'unknown'
+		if (regstatus[0] == 0): status = 'home'
+		elif (regstatus[0] == 1): status = 'roam'
+		elif (regstatus[0] == 2): status = 'roam_blink'
+		elif (regstatus[0] == 3): status = 'no serv.'
+		elif (regstatus[0] == 4): status = 'no serv. search'
+		elif (regstatus[0] == 5): status = 'no serv. no search'
+		elif (regstatus[0] == 6): status = 'no sim'
+		elif (regstatus[0] == 8): status = 'power off'
+		elif (regstatus[0] == 9): status = 'nsps'
+		elif (regstatus[0] == 10): status = 'nsps no cover.'
+		elif (regstatus[0] == 10): status = 'sim rejected'
+		else: status = 'unknown'
 
-                if (regstatus[5] == 0): network_type = 'home'
-                elif (regstatus[5] == 1): network_type = 'preferred'
-                elif (regstatus[5] == 2): network_type = 'forbidden'
-                elif (regstatus[5] == 2): network_type = 'other'
-                else: network_type = 'no network'
+		if (regstatus[5] == 0): network_type = 'home'
+		elif (regstatus[5] == 1): network_type = 'preferred'
+		elif (regstatus[5] == 2): network_type = 'forbidden'
+		elif (regstatus[5] == 2): network_type = 'other'
+		else: network_type = 'no network'
 
-                services = ""
-                if (regstatus[6] & 0x02): services += 'CS '
-                if (regstatus[6] & 0x01): services += 'GPRS '
-                if (regstatus[6] & 0x04): services += 'EGPRS '
-                if (regstatus[6] & 0x08): services += 'HSDPA '
-                if (regstatus[6] & 0x10): services += 'HSUPA'
-                fraction = 1.0 / 100 * signalstrength[0]
-                text = " - %d dBm" % signalstrength[1]
+		services = ""
+		if (regstatus[6] & 0x02): services += 'CS '
+		if (regstatus[6] & 0x01): services += 'GPRS '
+		if (regstatus[6] & 0x04): services += 'EGPRS '
+		if (regstatus[6] & 0x08): services += 'HSDPA '
+		if (regstatus[6] & 0x10): services += 'HSUPA'
+		fraction = 1.0 / 100 * signalstrength[0]
+		text = " - %d dBm" % signalstrength[1]
 
-                self.listWidget2.addItem("Phone Signal \t\t" + text.strip())
-                #self.lbl_pSignal_Info.setText(text)
+		self.listWidget2.addItem("Phone Signal \t\t" + text.strip())
+		#self.lbl_pSignal_Info.setText(text)
 
-                cell_id = regstatus[2] & 65535
-                cell_rnc = regstatus[2] >> 16
-                   
-                self.listWidget2.addItem("Cell RNC \t\t" + str(cell_rnc).strip())
-                ##
-                self.listWidget2.addItem("Cell Status \t\t" + status)
-                #self.lbl_pRNC_Info.setText(status)
-                self.listWidget2.addItem("Cell ID \t\t" + str(cell_id).strip())
-                #self.lbl_CellID_Info.setText(str(cell_id))
+		cell_id = regstatus[2] & 65535
+		cell_rnc = regstatus[2] >> 16
+		   
+		self.listWidget2.addItem("Cell RNC \t\t" + str(cell_rnc).strip())
+		##
+		self.listWidget2.addItem("Cell Status \t\t" + status)
+		#self.lbl_pRNC_Info.setText(status)
+		self.listWidget2.addItem("Cell ID \t\t" + str(cell_id).strip())
+		#self.lbl_CellID_Info.setText(str(cell_id))
 
-                self.listWidget2.addItem("Cell Services \t\t" + services)
-                #self.lbl_pServices_Info.setText(services)
-                print " ** Finishing Cellular **"
+		self.listWidget2.addItem("Cell Services \t\t" + services)
+		#self.lbl_pServices_Info.setText(services)
+		print " ** Finishing Cellular **"
 
 
 				
@@ -1290,8 +1423,12 @@ if __name__ == "__main__":
 	print " ** Draw everything and start the main function**"
 	ui.setupUi(MainWindow)
 	print " ** Show everything**"
+	
 	MainWindow.show()
+	#MainWindow.setAttribute(QtCore.WA_Maemo5ShowProgressIndicator, False)
 	print " ** Waiting for quit signal - healthcheck loaded **"
+	ui.updateAll()
+	
 	sys.exit(app.exec_())
 	print " ** sys.exit called**"
 
